<?php
/***************************************************************
*  Copyright notice
*
*  Based on t3mootools from Peter Klein <peter@umloud.dk>
*  (c) 2007-2009 Juergen Furrer (juergen.furrer@gmail.com)
*  All rights reserved
*
*  This script is part of the TYPO3 project. The TYPO3 project is
*  free software; you can redistribute it and/or modify
*  it under the terms of the GNU General Public License as published by
*  the Free Software Foundation; either version 2 of the License, or
*  (at your option) any later version.
*
*  The GNU General Public License can be found at
*  http://www.gnu.org/copyleft/gpl.html.
*  A copy is found in the textfile GPL.txt and important notices to the license
*  from the author is found in LICENSE.txt distributed with these scripts.
*
*
*  This script is distributed in the hope that it will be useful,
*  but WITHOUT ANY WARRANTY; without even the implied warranty of
*  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
*  GNU General Public License for more details.
*
*  This copyright notice MUST APPEAR in all copies of the script!
***************************************************************/

if (file_exists(t3lib_extMgm::siteRelPath('t3jquery').'res/jquery-ui-1.7.2.js')) {
	define('T3JQUERY', true);
}

/**
 * jQuery Javascript Loader functions
 *
 * You are encouraged to use this library in your own scripts!
 *
 * USE:
 * The class is intended to be used without creating an instance of it.
 * So: Don't instantiate - call functions with "tx_t3jquery::" prefixed the function name.
 * So use tx_t3jquery::[method-name] to refer to the functions, eg. 'tx_t3jquery::addJqJS()'
 *
 * Example:
 *
 * if (t3lib_extMgm::isLoaded('t3jquery')) {
 *   require_once(t3lib_extMgm::extPath('t3jquery').'class.tx_t3jquery.php');
 * }
 *
 *
 * if (T3JQUERY === true) {
 *   tx_t3jquery::addJqJS();
 * } else {
 *   // Here you add your own version of jQuery library, which is used if the
 *   // "t3jquery" extension is not installed.
 *   $GLOBALS['TSFE']->additionalHeaderData[] = ..
 * }
 *
 * @author Juergen Furrer (juergen.furrer@gmail.com)
 * @package TYPO3
 * @subpackage t3jquery
 */
class tx_t3jquery
{
	/**
	 * @var object
	 */
	var $cObj;

	/**
	 * Adds the jquery script tag for the page header.
	 * For frontend usage only.
	 * @return	void
	 */
	function addJqJS()
	{
		$GLOBALS['TSFE']->additionalHeaderData['jquery']  = chr(10).tx_t3jquery::getJqJS();
	}

	/**
	 * Get the jQuery UI script tag.
	 * For frontend usage only.
	 * @param	boolean		If true, only the URL is returned, not a full script tag
	 * @return	string		HTML Script tag to load the jQuery JavaScript library
	 */
	function getJqJS($urlOnly = false)
	{
		$url = t3lib_extMgm::siteRelPath('t3jquery').'res/jquery-ui-1.7.2.js';
		return $urlOnly ? $url : '<script type="text/javascript" src="'.$url.'"></script>';
	}

	/**
	 * Get the jquery script tag.
	 * For backend usage only.
	 * @param	boolean		If true, only the URL is returned, not a full script tag
	 * @return	string		HTML Script tag to load the jQuery JavaScript library
	 */
	function getJqJSBE($urlOnly = false)
	{
		global $BACK_PATH;
		$url = str_replace('typo3', t3lib_extMgm::siteRelPath('t3jquery'), $BACK_PATH).'res/jquery-ui-1.7.2.js';
		return $urlOnly ? $url : '<script type="text/javascript" src="'.$url.'"></script>';
	}

	/**
	 * Function to be used from TypoScript to add Javascript after the jquery.js
	 *
	 * This is a small wrapper for adding javascripts script after the jQuery Library.
	 * This is needed in some situations because headerdata added with "page.headerData" 
	 * is placed BEFORE the headerdata which is added using PHP.
	 *
	 * Usage:
	 *
	 *  10 = USER
	 *  10.userFunc = tx_t3jquery->addJS
	 *  10.jsfile = fileadmin/testscript.js
	 *  10.jsdata = alert('Hello World!');
	 * @param	string		$content: Content input, ignore (just put blank string)
	 * @param	array		$conf: TypoScript configuration of the plugin!
	 * @return	void
	 */
	function addJS($content, $conf)
	{
		// If the jQuery lib is not added to page yet, add it!
		if ($GLOBALS['TSFE']->additionalHeaderData['jquery'] == '') {
			tx_t3jquery::addJqJS();
		}
		// Append additional javascript to existing headerData.
		$jsdata = $this->cObj->stdWrap($conf['jsdata'], $conf['jsdata.']);
		$jsfile = preg_replace('|^'.PATH_site.'|i','', t3lib_div::getFileAbsFileName($this->cObj->stdWrap($conf['jsfile'], $conf['jsfile.'])));
		// 
		if ($jsfile!='') $GLOBALS['TSFE']->additionalHeaderData['jquery'] .= chr(10).'<script type="text/javascript" src="'.$jsfile.'"></script>';
		if ($jsdata!='') $GLOBALS['TSFE']->additionalHeaderData['jquery'] .= chr(10).'<script type="text/javascript">'.chr(10).'/*<![CDATA[*/'.chr(10).'<!--'.chr(10).$jsdata.chr(10).'// -->'.chr(10).'/*]]>*/'.chr(10).'</script>';
	}
}

if (defined('TYPO3_MODE') && $TYPO3_CONF_VARS[TYPO3_MODE]['XCLASS']['ext/t3jquery/class.tx_t3jquery.php'])	{
	include_once($TYPO3_CONF_VARS[TYPO3_MODE]['XCLASS']['ext/t3jquery/class.tx_t3jquery.php']);
}
?>
